@@ -392,7 +392,7 @@ def get_by_tag(tag, limit=None, file=None):
     """
     get doc by tag
     >>> clear(file=MEMORY_FILE)
-    >>> insert_many( [{'name': 'A'}, {'name': 'B'}, {'name': 'C'}], tag='name' )
+    >>> insert_many( [{'name': 'A'}, {'name': 'B'}, {'name': 'C'}], tag_name='name' )
     >>> get_by_tag('B')[0]['name']
     'B'
     """
@@ -417,7 +417,7 @@ def get(id=None, key=None, tag=None, file=None):
     """
     get doc by id or key
     >>> clear(file=MEMORY_FILE)
-    >>> insert_many([{'name': 'A'},{'name': 'B'},{'name': 'C'}], tag='name')
+    >>> insert_many([{'name': 'A'},{'name': 'B'},{'name': 'C'}], tag_name='name')
     >>> get(id=1)['name']
     'A'
     >>> get(tag='C')[0]['name']
@@ -445,6 +445,7 @@ def insert(value, file=None, tag_name=None, tag=None):
     2
     >>> [a['name'] for a in get_all()]
     ['A', 'B']
+
     insert doc with tag
     >>> clear()
     >>> insert({'name':'banana', 'price': 30}, tag='banana')
@@ -543,14 +544,14 @@ def update(id=None, new_value=None, tag=None):
 
     update by id:
     >>> clear()
-    >>> insert_many([{"name": "A", "age": 30}, {"name": "B", "age": 20}], tag="name")
+    >>> insert_many([{"name": "A", "age": 30}, {"name": "B", "age": 20}], tag_name="name")
     >>> update(id=2, new_value={"name":"B", "age": 10})
     >>> get_by_tag("B")[0]["age"]
     10
 
     update by tag:
     >>> clear()
-    >>> insert_many([{"name": "A", "age": 30}, {"name": "B", "age": 20}], tag="name")
+    >>> insert_many([{"name": "A", "age": 30}, {"name": "B", "age": 20}], tag_name="name")
     >>> update(tag="B", new_value={"name":"B", "age": 15})
     >>> get_by_tag("B")[0]["age"]
     15
@@ -582,7 +583,7 @@ def update_by_tag(tag, new_value):
     """
     update doc value by tag
     >>> clear()
-    >>> insert_many([{"name": "A", "age": 30}, {"name": "B", "age": 20}], tag="name")
+    >>> insert_many([{"name": "A", "age": 30}, {"name": "B", "age": 20}], tag_name="name")
     >>> update_by_tag("B", {"name":"B", "age": 15})
     >>> get_by_tag("B")[0]["age"]
     15
@@ -593,14 +594,14 @@ def update_by_id(id, new_value):
     """
     update doc value by tag
     >>> clear()
-    >>> insert_many([{"name": "A", "age": 30}, {"name": "B", "age": 20}], tag="name")
+    >>> insert_many([{"name": "A", "age": 30}, {"name": "B", "age": 20}], tag_name="name")
     >>> update_by_tag("B", {"name":"B", "age": 15})
     >>> get_by_tag("B")[0]["age"]
     15
     """
     update(id=id, new_value=new_value)
 
-def delete(id=None, key=None, tag=None, file=None):
+def delete(id=None, key=None, tag=None, doc_keys=None, file=None):
     """
     delete by id or key
     >>> clear(file=MEMORY_FILE)
@@ -608,12 +609,21 @@ def delete(id=None, key=None, tag=None, file=None):
     >>> delete(id=3)
     >>> [a for a in get_all()]
     [1, 2]
+
+    delete key in key-value store:
     >>> clear()
     >>> set_key('Taro', 30)
     >>> set_key('Jiro', 18)
     >>> delete(key='Taro')
     >>> list(get_keys())
     ['Jiro']
+
+    delete doc_keys in docs
+    >>> clear()
+    >>> insert_many([{'name': 'A'},{'name': 'B'},{'name': 'C'}])
+    >>> delete(doc_keys={'name': 'A'})
+    >>> len(get_all())
+    2
     """
     if file is not None:
         connect(file)
@@ -634,6 +644,12 @@ def delete(id=None, key=None, tag=None, file=None):
     if key is not None:
         delete_key(key)
         return
+    if doc_keys is not None:
+        docs = find(keys=doc_keys)
+        for row in docs:
+            id = row['id']
+            delete(id=id)
+        return
     raise Exception('should set id or key in `delete` method')
 
 def clear_doc(file=None):
